@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2023 IRCAD France
+ * Copyright (C) 2009-2025 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,16 +22,16 @@
 
 #include "app/extension/config.hpp"
 
+#include <core/id.hpp>
+#include <core/runtime/helper.hpp>
 #include <core/runtime/module.hpp>
 #include <core/runtime/runtime.hpp>
 
-#include <data/composite.hpp>
+#include <data/map.hpp>
 #include <data/string.hpp>
 
 #include <boost/algorithm/string.hpp>
 
-#include <regex>
-
 namespace sight::app::extension
 {
 
@@ -39,6 +39,9 @@ std::string config::s_mandatory_parameter_identifier = "@mandatory@";
 
 config::uid_definition_t config::s_uid_definition_dictionary = {{"object", "uid"},
     {"service", "uid"},
+    {"updater", "uid"},
+    {"sequence", "uid"},
+    {"parallel", "uid"},
     {"view", "sid"},
     {"view", "wid"},
     {"editor", "wid"},
@@ -47,11 +50,40 @@ config::uid_definition_t config::s_uid_definition_dictionary = {{"object", "uid"
     {"menuItem", "sid"},
     {"channel", "uid"},
 };
-static const std::regex IS_VARIABLE(R"(\$\{.*\}.*)");
+
+static constexpr auto VARIABLE_PREFIX = "${";
+static constexpr auto VARIABLE_SUFFIX = "}";
+
+//------------------------------------------------------------------------------
+
+static constexpr bool is_variable(const std::string_view& _str)
+{
+    return _str.starts_with(VARIABLE_PREFIX);
+}
+
+//------------------------------------------------------------------------------
+
+inline static std::string to_variable(const std::string_view& _str)
+{
+    std::string variable(VARIABLE_PREFIX);
+    return variable.append(_str).append(VARIABLE_SUFFIX);
+}
+
+/// Boost algorithm replace_all is less efficient (but still better than a regex)
+/// This kind of replace_all is the best we can get for moderate size strings
+inline static void replace_all(std::string& _str, const std::string_view& _old, const std::string_view& _new)
+{
+    for(size_t find_pos = _str.find(_old) ;
+        find_pos != std::string::npos ;
+        find_pos = _str.find(_old, _new.length() + find_pos))
+    {
+        _str.replace(find_pos, _old.length(), _new);
+    }
+}
 
 //-----------------------------------------------------------------------------
 
-config::sptr config::get_default()
+config::sptr config::get()
 {
     static config::sptr s_current_app_config = std::make_shared<config>();
     return s_current_app_config;
@@ -71,14 +103,44 @@ void config::parse_plugin_infos()
         const auto desc      = app_config.get<std::string>("desc", "No description available");
 
         app_info::parameters_t parameters;
+        app_info::objects_t objects;
 
         if(const auto parameters_cfg = app_config.get_child_optional("parameters"); parameters_cfg.has_value())
         {
             for(const auto& param : boost::make_iterator_range(parameters_cfg->equal_range("param")))
             {
                 const auto name = param.second.get<std::string>("<xmlattr>.name");
+
+                SIGHT_ASSERT("Parameter " << std::quoted(name) << " already declared", !parameters.contains(name));
+                SIGHT_ASSERT(
+                    "Parameter " << std::quoted(name) << " already declared as object",
+                    !objects.contains(name)
+                );
                 parameters[name] = param.second.get<std::string>("<xmlattr>.default", s_mandatory_parameter_identifier);
             }
+
+            for(const auto& object : boost::make_iterator_range(parameters_cfg->equal_range("object")))
+            {
+                const auto uid = object.second.get<std::string>("<xmlattr>.uid");
+
+                SIGHT_ASSERT("Object " << std::quoted(uid) << " already declared", !objects.contains(uid));
+                SIGHT_ASSERT(
+                    "Object " << std::quoted(uid) << " already declared as parameter",
+                    !parameters.contains(uid)
+                );
+
+                objects[uid]  = {
+                    .type     = object.second.get<std::string>("<xmlattr>.type"),
+                    .deferred = object.second.get<bool>("<xmlattr>.deferred", false),
+                    .optional = object.second.get<bool>("<xmlattr>.optional", false),
+                    .value    = object.second.get<std::string>("<xmlattr>.value", "")
+                };
+
+                SIGHT_ERROR_IF(
+                    "Value specified for non-optional object parameter : " << std::quoted(uid),
+                    !objects[uid].value.empty() && !objects[uid].optional
+                );
+            }
         }
 
         // Get config
@@ -89,17 +151,18 @@ void config::parse_plugin_infos()
         std::string module_id                         = module->identifier();
 
         // Add app info
-        this->addapp_info(config_id, group, desc, parameters, config, module_id);
+        this->add_app_info(config_id, group, desc, parameters, objects, config, module_id);
     }
 }
 
 //-----------------------------------------------------------------------------
 
-void config::addapp_info(
+void config::add_app_info(
     const std::string& _config_id,
     const std::string& _group,
     const std::string& _desc,
     const app_info::parameters_t& _parameters,
+    const app_info::objects_t& _objects,
     const core::runtime::config_t& _config,
     const std::string& _module_id
 )
@@ -117,17 +180,13 @@ void config::addapp_info(
     info->desc        = _desc;
     info->config      = _config;
     info->parameters  = _parameters;
+    info->objects     = _objects;
     info->module_id   = _module_id;
     m_reg[_config_id] = info;
 }
 
 //-----------------------------------------------------------------------------
 
-config::config()
-= default;
-
-//-----------------------------------------------------------------------------
-
 void config::clear_registry()
 {
     core::mt::write_lock lock(m_registry_mutex);
@@ -139,8 +198,8 @@ void config::clear_registry()
 core::runtime::config_t config::get_adapted_template_config(
     const std::string& _config_id,
     const field_adaptor_t _field_adaptors,
-    bool _auto_prefix_id
-) const
+    const std::string& _auto_prefix_id
+)
 {
     core::mt::read_lock lock(m_registry_mutex);
     // Get config template
@@ -151,49 +210,113 @@ core::runtime::config_t config::get_adapted_template_config(
     );
 
     // Adapt config
-    core::runtime::config_t new_config;
+    core::runtime::config_t new_config = iter->second->config;
 
     field_adaptor_t fields;
-    app_info::parameters_t parameters = iter->second->parameters;
 
-    for(const auto& param : parameters)
+    for(const auto& param : iter->second->parameters)
     {
-        auto iter_field       = _field_adaptors.find(param.first);
-        const std::string key = "\\$\\{" + param.first + "\\}";
-        if(iter_field != _field_adaptors.end())
+        const std::string variable = to_variable(param.first);
+        if(auto iter_field = _field_adaptors.find(param.first); iter_field != _field_adaptors.end())
         {
-            fields[key] = iter_field->second;
+            fields[variable] = iter_field->second;
         }
         else if(param.second != s_mandatory_parameter_identifier)
         {
-            fields[key] = param.second;
+            fields[variable] = param.second;
         }
         else
         {
-            SIGHT_THROW(
-                "Parameter : '" << param.first << "' is needed by the app configuration id='" << _config_id
-                << "'."
-            );
+            SIGHT_THROW("[" << _config_id << "] parameter : " << std::quoted(param.first) << " is needed");
         }
     }
 
-    std::string auto_prefix_name;
-    if(_auto_prefix_id)
+    for(const auto& object : iter->second->objects)
     {
-        auto_prefix_name = sight::app::extension::config::get_unique_identifier(_config_id);
+        const std::string variable      = to_variable(object.first);
+        bool object_passed_as_parameter = false;
+
+        if(const auto iter_field = _field_adaptors.find(object.first); iter_field != _field_adaptors.end())
+        {
+            fields[variable]           = iter_field->second;
+            object_passed_as_parameter = true;
+        }
+        else
+        {
+            // The object is not passed as parameter
+            if(object.second.deferred || object.second.optional)
+            {
+                SIGHT_INFO(
+                    "[" << _config_id << "] deferred or optional object parameter " << std::quoted(object.first)
+                    << " not provided"
+                );
+            }
+            else
+            {
+                SIGHT_THROW("[" << _config_id << "] parameter : " << std::quoted(object.first) << " is needed");
+            }
+        }
+
+        core::runtime::config_t object_ref_cfg;
+        object_ref_cfg.put("<xmlattr>.type", object.second.type);
+        if(object.second.deferred)
+        {
+            object_ref_cfg.put("<xmlattr>.uid", variable);
+            object_ref_cfg.put("<xmlattr>.deferred", "true");
+        }
+        else if(object_passed_as_parameter)
+        {
+            object_ref_cfg.put("<xmlattr>.uid", variable);
+            object_ref_cfg.put("<xmlattr>.reference", "true");
+        }
+        else if(object.second.optional)
+        {
+            object_ref_cfg.put("<xmlattr>.uid", object.first);
+            if(!object.second.value.empty())
+            {
+                object_ref_cfg.put("<xmlattr>.value", object.second.value);
+            }
+        }
+
+        new_config.add_child("object", object_ref_cfg);
     }
 
+    std::function<void(const boost::property_tree::ptree&)> find_object_uids =
+        [&](const boost::property_tree::ptree& _tree)
+        {
+            for(const auto& it : _tree)
+            {
+                if(it.first == "object")
+                {
+                    if(const auto& attributes = it.second.get_child_optional("<xmlattr>"); attributes.has_value())
+                    {
+                        for(const auto& attribute : *attributes)
+                        {
+                            const auto attr_value = attribute.second.get_value<std::string>();
+                            if("uid" == attribute.first && !is_variable(attr_value))
+                            {
+                                fields[to_variable(attr_value)] = core::id::join(_auto_prefix_id, attr_value);
+                            }
+                        }
+                    }
+                }
+
+                find_object_uids(it.second);
+            }
+        };
+    find_object_uids(new_config);
+
     uid_parameter_replace_t parameter_replace_adaptors;
     sight::app::extension::config::collect_uid_for_parameter_replace(
         "config",
-        iter->second->config,
+        new_config,
         parameter_replace_adaptors
     );
     new_config = sight::app::extension::config::adapt_config(
-        iter->second->config,
+        new_config,
         fields,
         parameter_replace_adaptors,
-        auto_prefix_name
+        _auto_prefix_id
     );
 
     return new_config;
@@ -201,19 +324,6 @@ core::runtime::config_t config::get_adapted_template_config(
 
 //-----------------------------------------------------------------------------
 
-core::runtime::config_t config::get_adapted_template_config(
-    const std::string& _config_id,
-    data::composite::csptr _replace_fields,
-    bool _auto_prefix_id
-)
-const
-{
-    field_adaptor_t field_adaptors = composite_to_field_adaptor(_replace_fields);
-    return this->get_adapted_template_config(_config_id, field_adaptors, _auto_prefix_id);
-}
-
-//-----------------------------------------------------------------------------
-
 std::shared_ptr<core::runtime::module> config::get_module(const std::string& _config_id)
 {
     auto iter = m_reg.find(_config_id);
@@ -261,7 +371,7 @@ std::vector<std::string> config::get_configs_from_group(const std::string& _grou
 
 //-----------------------------------------------------------------------------
 
-field_adaptor_t config::composite_to_field_adaptor(data::composite::csptr _field_adaptors)
+field_adaptor_t config::map_to_field_adaptor(data::map::csptr _field_adaptors)
 {
     field_adaptor_t fields;
     for(const auto& elem : *_field_adaptors)
@@ -276,23 +386,15 @@ field_adaptor_t config::composite_to_field_adaptor(data::composite::csptr _field
 
 std::string config::get_unique_identifier(const std::string& _service_uid)
 {
-    static core::mt::mutex s_id_mutex;
-    core::mt::scoped_lock lock(s_id_mutex);
+    static std::mutex s_id_mutex;
+    std::unique_lock lock(s_id_mutex);
 
     static unsigned int srv_cpt = 1;
-    std::stringstream sstr;
 
-    if(_service_uid.empty())
-    {
-        sstr << "config_manager_" << srv_cpt;
-    }
-    else
-    {
-        sstr << _service_uid << "_" << srv_cpt;
-    }
-
-    ++srv_cpt;
-    return sstr.str();
+    return core::id::join(
+        _service_uid.empty() ? "config_manager" : _service_uid,
+        srv_cpt++
+    );
 }
 
 //-----------------------------------------------------------------------------
@@ -314,7 +416,7 @@ void config::collect_uid_for_parameter_replace(
             for(auto it = range.first ; it != range.second ; ++it)
             {
                 const auto attr_value = attribute.second.get_value<std::string>();
-                if(it->second == attribute.first && !std::regex_match(attr_value, IS_VARIABLE))
+                if(it->second == attribute.first && !is_variable(attr_value))
                 {
                     _replace_map.insert(attr_value);
                 }
@@ -346,57 +448,43 @@ core::runtime::config_t config::adapt_config(
 )
 {
     core::runtime::config_t result;
-    result.put_value<std::string>(adapt_field(_cfg_elem.get_value<std::string>(), _field_adaptors));
+    result.put_value<std::string>(subst_var(_cfg_elem.get_value<std::string>(), _field_adaptors));
 
-    const auto& attributes = _cfg_elem.get_child_optional("<xmlattr>");
-
-    if(attributes)
+    if(const auto& attributes = _cfg_elem.get_child_optional("<xmlattr>"); attributes.has_value())
     {
         for(const auto& attribute : *attributes)
         {
             const auto attribute_value = attribute.second.get_value<std::string>();
 
             // Add the config prefix for unique identifiers
-            if(!_auto_prefix_id.empty())
+            if(!_auto_prefix_id.empty() && !is_variable(attribute_value))
             {
                 if(attribute.first == "uid"
                    || attribute.first == "sid"
                    || attribute.first == "wid"
                    || attribute.first == "channel")
                 {
-                    // Detect if we have a variable name
-                    if(!std::regex_match(attribute_value, IS_VARIABLE))
+                    // This is not a variable, add the prefix
+                    result.put("<xmlattr>." + attribute.first, core::id::join(_auto_prefix_id, attribute_value));
+                    continue;
+                }
+
+                // Special case for <parameter replace="..." by="..." />
+                if(attribute.first == "by")
+                {
+                    // Look inside the map of potential replacements
+                    if(_uid_parameter_replace.find(attribute_value) != _uid_parameter_replace.end())
                     {
-                        // This is not a variable, add the prefix
                         result.put(
                             "<xmlattr>." + attribute.first,
-                            _auto_prefix_id + "_" + adapt_field(attribute_value, _field_adaptors)
+                            core::id::join(_auto_prefix_id, attribute_value)
                         );
                         continue;
                     }
                 }
-                // Special case for <parameter replace="..." by="..." />
-                else if(attribute.first == "by")
-                {
-                    // Detect if we have a variable name
-                    if(!std::regex_match(attribute_value, IS_VARIABLE))
-                    {
-                        // Look inside the map of potential replacements
-                        auto it_param = _uid_parameter_replace.find(attribute_value);
-                        if(it_param != _uid_parameter_replace.end())
-                        {
-                            result.put(
-                                "<xmlattr>." + attribute.first,
-                                _auto_prefix_id + "_"
-                                + adapt_field(attribute_value, _field_adaptors)
-                            );
-                            continue;
-                        }
-                    }
-                }
             }
 
-            result.put("<xmlattr>." + attribute.first, adapt_field(attribute_value, _field_adaptors));
+            result.put("<xmlattr>." + attribute.first, subst_var(attribute_value, _field_adaptors));
         }
     }
 
@@ -406,15 +494,13 @@ core::runtime::config_t config::adapt_config(
         if(!_auto_prefix_id.empty() && (sub_elem.first == "signal" || sub_elem.first == "slot"))
         {
             // Detect if we have a variable name
-            if(!std::regex_match(sub_elem.second.get_value<std::string>(), IS_VARIABLE))
+            if(const auto& sub_elem_value = sub_elem.second.get_value<std::string>(); !is_variable(sub_elem_value))
             {
                 // This is not a variable, add the prefix
                 core::runtime::config_t elt;
-                elt.put_value(_auto_prefix_id + "_" + sub_elem.second.get_value<std::string>());
+                elt.put_value(core::id::join(_auto_prefix_id, sub_elem_value));
 
-                const auto& sub_attributes = _cfg_elem.get_child_optional("<xmlattr>");
-
-                if(sub_attributes)
+                if(const auto& sub_attributes = _cfg_elem.get_child_optional("<xmlattr>"); sub_attributes)
                 {
                     for(const auto& attribute : *sub_attributes)
                     {
@@ -438,36 +524,21 @@ core::runtime::config_t config::adapt_config(
 
 //-----------------------------------------------------------------------------
 
-std::string config::adapt_field(const std::string& _str, const field_adaptor_t& _variables_map)
+std::string config::subst_var(std::string _str, const field_adaptor_t& _variables_map)
 {
-    std::string new_str = _str;
-    if(!_str.empty())
+    if(!_str.empty() && is_variable(_str))
     {
         // Discriminate first variable expressions only, looking through all keys of the replace map is not for free
         // However we look inside the whole string instead of only at the beginning because we want  to replace "inner"
         // variables as well, i.e. not only ${uid} but also uid${suffix}
-        if(std::regex_search(_str, IS_VARIABLE))
+        // Iterate over all variables
+        for(const auto& [variable, value] : _variables_map)
         {
-            // Iterate over all variables
-            for(const auto& field_adaptor : _variables_map)
-            {
-                const std::regex var_regex("(.*)" + field_adaptor.first + "(.*)");
-                if(std::regex_match(_str, var_regex))
-                {
-                    const std::string var_replace("\\1" + field_adaptor.second + "\\2");
-                    new_str = std::regex_replace(
-                        new_str,
-                        var_regex,
-                        var_replace,
-                        std::regex_constants::match_default
-                        | std::regex_constants::format_sed
-                    );
-                }
-            }
+            replace_all(_str, variable, value);
         }
     }
 
-    return new_str;
+    return _str;
 }
 
 //-----------------------------------------------------------------------------
