@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2024 IRCAD France
+ * Copyright (C) 2009-2025 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -62,7 +62,7 @@ namespace medical_image
 using index_t = std::array<int, 3>;
 using vec3_t  = std::array<double, 3>;
 
-enum orientation_t
+enum axis_t
 {
     /// Directions.
     x_axis = 0,
@@ -105,13 +105,13 @@ SIGHT_DATA_API bool check_image_validity(const data::image& _p_img);
 SIGHT_DATA_API bool check_image_slice_index(data::image::sptr _p_img);
 
 /**
- * @brief Checks if buf contains zero, from begin to begin + len
+ * @brief Checks if image buffer contains zero, from begin to begin + len
  *
- * @param _buf data::image::buffer_t* begin of the buffer.
+ * @param _buffer data::image::buffer_t* begin of the buffer.
  * @param _len unsigned int length, as begin+len.
  * @return boolean, true if null, false otherwise.
  */
-SIGHT_DATA_API bool is_buf_null(const data::image::buffer_t* _buf, unsigned int _len);
+SIGHT_DATA_API bool is_buf_null(const data::image::buffer_t* _buffer, unsigned int _len);
 
 /**
  * @brief Return a buffer of image type's size, containing 'value' casted to image data type
@@ -123,31 +123,12 @@ SPTR(data::image::buffer_t) get_pixel_in_image_space(data::image::sptr _image, T
 
 /**
  * @brief Return minimum and maximum values contained in image. If image
- * min or max value is out of MINMAXTYPE range, they are clamped to
- * MINMAXTYPE capacity
+ * min or max value is out of T range, they are clamped to T capacity
  * @param[in] _img : image
- * @param[out] _min : minimum value
- * @param[out] _max : maximum value
+ * @return: minimum value and maximum value
  */
-template<typename MINMAXTYPE>
-void get_min_max(data::image::csptr _img, MINMAXTYPE& _min, MINMAXTYPE& _max);
-
-/**
- * @brief Compute the indices of a 3D position inside an image. Beware, to be as generic as possible, no boundary check
- * is performed so it can lie outside the image. If you want to use it to access a voxel inside the image, be sure to
- * make these checks first and handle what you want to do in this case.
- * @param[in] _image : input image
- * @param[in] _pos : the 3D coordinates of the voxel
- * @return: the indices of the voxel
- */
-SIGHT_DATA_API index_t compute_voxel_indices(const data::image& _image, const vec3_t& _pos);
-
-/**
- * @brief Return the bounding box surrounding an image.
- * @param[in] _image : input image
- * @return: the bounding box as the minimum and a maximum coordinates
- */
-SIGHT_DATA_API std::pair<vec3_t, vec3_t> compute_bounding_box(const data::image& _image);
+template<typename T>
+[[nodiscard]] std::pair<T, T> get_min_max(data::image::csptr _img);
 
 // Getter/Setter for specific image fields
 
@@ -156,51 +137,52 @@ SIGHT_DATA_API std::pair<vec3_t, vec3_t> compute_bounding_box(const data::image&
  * Frontal).
  *
  * @param _image : input image reference
- * @param _orientation : desired orientation
+ * @param _axis : desired orientation
  * @return the current index as a std::int64_t.
  */
 SIGHT_DATA_API std::optional<std::int64_t> get_slice_index(
     const data::image& _image,
-    const orientation_t& _orientation
+    const axis_t& _axis
 );
 
 /**
- * @brief Helper function to get current slice position on a medical image in a specific orientation (Axial, Sagittal,
+ * @brief Helper function to set current slice index on a medical image in a specific axis (Axial, Sagittal,
  * Frontal).
  *
  * @param _image : input image reference
- * @param _orientation : desired orientation
- * @return the current position as a double_t.
- */
-
-SIGHT_DATA_API std::optional<double_t> get_slice_position(const data::image& _image, const orientation_t& _orientation);
-/**
- * @brief Helper function to set current slice index on a medical image in a specific orientation (Axial, Sagittal,
- * Frontal).
- *
- * @param _image : input image reference
- * @param _orientation : desired orientation.
+ * @param _axis : desired orientation.
  * @param _slice_count : current slice index to set as std::int64_t.
  */
 SIGHT_DATA_API void set_slice_index(
     data::image& _image,
-    const orientation_t& _orientation,
+    const axis_t& _axis,
     std::int64_t _slice_count
 );
 
 /**
- * @brief Helper function to set current slice position on a medical image in a specific orientation (Axial, Sagittal,
- * Frontal).
+ * @brief Helper function to get current slice position on a medical image in a specific orientation (Axial, Sagittal,
+ * Frontal). The position (in mm) is in image coordinates, as the image orientation is ignored.
  *
  * @param _image : input image reference
- * @param _orientation : desired orientation.
- * @param _position  : current slice position to set as double_t.
+ * @param _axis : desired orientation
+ * @return the current slice position (mm) in image.
+ */
+
+SIGHT_DATA_API std::optional<double> get_slice_position(const data::image& _image, const axis_t& _axis);
+
+/**
+ * @brief Helper function to set current slice position on a medical image in a specific axis (Axial, Sagittal,
+ * Frontal). The position (in mm) is in image coordinates, as the image orientation is ignored.
+ *
+ * @param _image : input image reference
+ * @param _axis : desired orientation.
+ * @param _position  : slice position (mm) in image to set.
  */
 
 SIGHT_DATA_API void set_slice_position(
     data::image& _image,
-    const orientation_t& _orientation,
-    double_t& _position
+    const axis_t& _axis,
+    double _position
 );
 
 /**
@@ -219,37 +201,6 @@ SIGHT_DATA_API data::point_list::sptr get_landmarks(const data::image& _image);
  */
 SIGHT_DATA_API void set_landmarks(data::image& _image, const data::point_list::sptr& _landmarks);
 
-/**
- * @brief Helper function to calculate the slice index of a given fiducial point in a specified orientation within a
- * medical image.
- *
- * @param _image : The input image as a constant reference to data::image.
- * @param _point : The coordinates of the fiducial point as a std::array of three doubles.
- * @param _orientation : The orientation (axial, sagittal, or frontal) to calculate the slice index.
- * @return std::optional<std::int64_t> : The calculated slice index as an integer.
- */
-
-SIGHT_DATA_API std::optional<std::int64_t> get_fiducial_slice_index(
-    const data::image& _image,
-    const std::array<double,
-                     3>& _point,
-    orientation_t _orientation
-);
-
-/**
- * @brief Helper function to calculate the physical position of a given fiducial point along a specified slice
- * orientation within a medical image.
- *
- * @param _image : The input image as a constant reference to data::image.
- * @param _point : The coordinates of the fiducial point as a std::array of three doubles.
- * @param _orientation : The orientation (axial, sagittal, or frontal) to calculate the physical slice position.
- * @return std::optional<double> : The calculated physical position as a double.
- */
-SIGHT_DATA_API std::optional<double> get_fiducial_slice_position(
-    const data::image& _image,
-    const std::array<double, 3>& _point,
-    orientation_t _orientation
-);
 /**
  * @brief Helper function to get distances vector of a medical image.
  *
@@ -331,18 +282,25 @@ SIGHT_DATA_API std::string get_label(const data::image& _image);
 SIGHT_DATA_API void set_label(data::image& _image, const std::string& _label);
 
 /**
+ * @deprecated Use sight::data::image::get_direction() instead
  * @brief Helper function to get the direction field from an image data.
  *
  * @param _image : input image reference.
  */
-SIGHT_DATA_API data::matrix4::sptr get_direction(const data::image& _image);
+[[deprecated("Use sight::data::image::orientation() instead")]] SIGHT_DATA_API data::matrix4::sptr get_direction(
+    const data::image& _image
+);
 
 /**
+ * @deprecated Use sight::data::image::set_orientation() instead
  * @brief Helper function to set the direction field from an image data.
  *
  * @param _image : input image reference.
  */
-SIGHT_DATA_API void set_direction(data::image& _image, data::matrix4::sptr _direction);
+[[deprecated("Use sight::data::image::set_orientation() instead")]] SIGHT_DATA_API void set_direction(
+    data::image& _image,
+    data::matrix4::sptr _direction
+);
 
 // ------------------------------------------------------------------------------
 
@@ -548,13 +506,17 @@ public:
 
 // ------------------------------------------------------------------------------
 
-template<typename MINMAXTYPE>
-void get_min_max(const data::image::csptr _img, MINMAXTYPE& _min, MINMAXTYPE& _max)
+template<typename T>
+std::pair<T, T> get_min_max(const data::image::csptr _img)
 {
-    typename min_max_functor<MINMAXTYPE>::param param(_img, _min, _max);
+    T min = std::numeric_limits<T>::max();
+    T max = std::numeric_limits<T>::min();
+    typename min_max_functor<T>::param param(_img, min, max);
 
     core::type type = _img->type();
-    core::tools::dispatcher<core::tools::supported_dispatcher_types, min_max_functor<MINMAXTYPE> >::invoke(type, param);
+    core::tools::dispatcher<core::tools::supported_dispatcher_types, min_max_functor<T> >::invoke(type, param);
+
+    return {min, max};
 }
 
 } // namespace sight::data::helper::medical_image
