@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2016 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,17 +22,17 @@
 
 #include "filter/dicom/registry/detail.hpp"
 
-#include <core/LazyInstantiator.hpp>
+#include <core/lazy_instantiator.hpp>
 
 namespace sight::filter::dicom::registry
 {
 
-struct FwDicomIOFilterRegistryInstantiatorTag {};
+struct dicom_io_filter_registry_instantiator_tag {};
 
-SPTR(Type) get()
+SPTR(type) get()
 {
-    using InstantiatorType = core::LazyInstantiator<Type, FwDicomIOFilterRegistryInstantiatorTag>;
-    return InstantiatorType::getInstance();
+    using instantiator_t = core::lazy_instantiator<type, dicom_io_filter_registry_instantiator_tag>;
+    return instantiator_t::get_instance();
 }
 
 } // namespace sight::filter::dicom::registry
