@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2018-2023 IRCAD France
+ * Copyright (C) 2018-2024 IRCAD France
  * Copyright (C) 2018-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -55,12 +55,13 @@ void line_drawer_test::tearDown()
 void line_drawer_test::circle_test()
 {
     {
-        const data::image::size_t size       = {{120, 120, 120}};
-        const data::image::spacing_t spacing = {{1., 1., 1.}};
-        const data::image::origin_t origin   = {{0., 0., 0.}};
-        const core::type type                = core::type::INT16;
+        const data::image::size_t size               = {120, 120, 120};
+        const data::image::spacing_t spacing         = {1., 1., 1.};
+        const data::image::origin_t origin           = {0., 0., 0.};
+        const data::image::orientation_t orientation = {0.36, 0.48, -0.8, -0.8, 0.6, 0.0, 0.48, 0.64, 0.6};
+        const core::type type                        = core::type::INT16;
 
-        const filter::image::line_drawer::coordinates_t point = {{20, 20, 20}};
+        const filter::image::line_drawer::coordinates_t point = {20, 20, 20};
         const double thickness                                = 0.0001;
         const std::int16_t value                              = 152;
 
@@ -71,8 +72,9 @@ void line_drawer_test::circle_test()
             size,
             spacing,
             origin,
+            orientation,
             type,
-            data::image::pixel_format::gray_scale
+            data::image::pixel_format_t::gray_scale
         );
 
         const auto dump_lock = image->dump_lock();
@@ -99,12 +101,13 @@ void line_drawer_test::circle_test()
     }
 
     {
-        const data::image::size_t size       = {{120, 120, 120}};
-        const data::image::spacing_t spacing = {{1., 1., 1.}};
-        const data::image::origin_t origin   = {{0., 0., 0.}};
-        const core::type type                = core::type::INT16;
+        const data::image::size_t size               = {120, 120, 120};
+        const data::image::spacing_t spacing         = {1., 1., 1.};
+        const data::image::origin_t origin           = {0., 0., 0.};
+        const data::image::orientation_t orientation = {0.36, 0.48, -0.8, -0.8, 0.6, 0.0, 0.48, 0.64, 0.6};
+        const core::type type                        = core::type::INT16;
 
-        const filter::image::line_drawer::coordinates_t point = {{20, 20, 20}};
+        const filter::image::line_drawer::coordinates_t point = {20, 20, 20};
 
         const double thickness   = 5;
         const std::int16_t value = 152;
@@ -116,8 +119,9 @@ void line_drawer_test::circle_test()
             size,
             spacing,
             origin,
+            orientation,
             type,
-            data::image::pixel_format::gray_scale
+            data::image::pixel_format_t::gray_scale
         );
         const auto dump_lock = image->dump_lock();
 
@@ -240,12 +244,13 @@ void line_drawer_test::circle_test()
 void line_drawer_test::ellipse_test()
 {
     {
-        const data::image::size_t size       = {{120, 120, 120}};
-        const data::image::spacing_t spacing = {{1., 4., 1.}};
-        const data::image::origin_t origin   = {{0., 0., 0.}};
-        const core::type type                = core::type::INT16;
+        const data::image::size_t size               = {120, 120, 120};
+        const data::image::spacing_t spacing         = {1., 4., 1.};
+        const data::image::origin_t origin           = {0., 0., 0.};
+        const data::image::orientation_t orientation = {0.36, 0.48, -0.8, -0.8, 0.6, 0.0, 0.48, 0.64, 0.6};
+        const core::type type                        = core::type::INT16;
 
-        const filter::image::line_drawer::coordinates_t point = {{50, 50, 50}};
+        const filter::image::line_drawer::coordinates_t point = {50, 50, 50};
 
         const double thickness   = 10;
         const std::int16_t value = 152;
@@ -257,8 +262,9 @@ void line_drawer_test::ellipse_test()
             size,
             spacing,
             origin,
+            orientation,
             type,
-            data::image::pixel_format::gray_scale
+            data::image::pixel_format_t::gray_scale
         );
 
         const auto dump_lock = image->dump_lock();
@@ -348,12 +354,13 @@ void line_drawer_test::ellipse_test()
 void line_drawer_test::border_test()
 {
     {
-        const data::image::size_t size       = {{50, 50, 50}};
-        const data::image::spacing_t spacing = {{2., 4., 8.}};
-        const data::image::origin_t origin   = {{0., 0., 0.}};
-        const core::type type                = core::type::INT16;
+        const data::image::size_t size               = {50, 50, 50};
+        const data::image::spacing_t spacing         = {2., 4., 8.};
+        const data::image::origin_t origin           = {0., 0., 0.};
+        const data::image::orientation_t orientation = {0.36, 0.48, -0.8, -0.8, 0.6, 0.0, 0.48, 0.64, 0.6};
+        const core::type type                        = core::type::INT16;
 
-        const filter::image::line_drawer::coordinates_t point = {{45, 3, 20}};
+        const filter::image::line_drawer::coordinates_t point = {45, 3, 20};
 
         const double thickness   = 15;
         const std::int16_t value = 1952;
@@ -365,8 +372,9 @@ void line_drawer_test::border_test()
             size,
             spacing,
             origin,
+            orientation,
             type,
-            data::image::pixel_format::gray_scale
+            data::image::pixel_format_t::gray_scale
         );
 
         const auto dump_lock = image->dump_lock();
@@ -425,14 +433,15 @@ void line_drawer_test::border_test()
 void line_drawer_test::roi_test()
 {
     {
-        const data::image::size_t size       = {{150, 150, 150}};
-        const data::image::spacing_t spacing = {{2., 4., 8.}};
-        const data::image::origin_t origin   = {{0., 0., 0.}};
-        const core::type type                = core::type::INT16;
+        const data::image::size_t size             = {150, 150, 150};
+        const data::image::spacing_t spacing       = {2., 4., 8.};
+        const data::image::origin_t origin         = {0., 0., 0.};
+        const data::image::orientation_t direction = {0.36, 0.48, -0.8, -0.8, 0.6, 0.0, 0.48, 0.64, 0.6};
+        const core::type type                      = core::type::INT16;
 
-        const filter::image::line_drawer::coordinates_t point = {{45, 45, 40}};
+        const filter::image::line_drawer::coordinates_t point = {45, 45, 40};
 
-        const data::helper::medical_image::orientation_t orientation =
+        const data::helper::medical_image::axis_t orientation =
             data::helper::medical_image::z_axis;
         const double thickness   = 15;
         const std::int16_t value = 1952;
@@ -445,16 +454,18 @@ void line_drawer_test::roi_test()
             size,
             spacing,
             origin,
+            direction,
             type,
-            data::image::pixel_format::gray_scale
+            data::image::pixel_format_t::gray_scale
         );
         utest_data::generator::image::generate_image(
             roi_image,
             size,
             spacing,
             origin,
+            direction,
             type,
-            data::image::pixel_format::gray_scale
+            data::image::pixel_format_t::gray_scale
         );
 
         const auto roi_dump_lock = roi_image->dump_lock();
