@@ -213,6 +213,7 @@ void synchronizer::starting()
 
 void synchronizer::updating()
 {
+    this->synchronize();
 }
 
 // ----------------------------------------------------------------------------
@@ -426,7 +427,10 @@ void synchronizer::copy_frame_from_tl_to_output(
             // Check if frame dimensions have changed
             if(frame_tl_size != frame->size() || frame_tl_num_components != frame->num_components())
             {
-                enum data::image::pixel_format format {data::image::undefined};
+                enum data::image::pixel_format_t format
+                {
+                    data::image::undefined
+                };
                 switch(frame_tl_pixel_format)
                 {
                     case data::frame_tl::pixel_format::gray_scale:
@@ -470,7 +474,7 @@ void synchronizer::copy_frame_from_tl_to_output(
             if(auto image_series =
                    std::dynamic_pointer_cast<sight::data::image_series>(frame.get_shared()); image_series)
             {
-                image_series->set_frame_acquisition_time_point(_synchronization_timestamp);
+                image_series->set_frame_acquisition_time_point(_synchronization_timestamp, 0);
             }
 
             const std::uint8_t* frame_buff = &buffer->get_element(frame_tl_element_index);
@@ -548,7 +552,8 @@ void synchronizer::copy_matrix_from_tl_to_output(
     else
     {
         SIGHT_ERROR(
-            "Buffer not found for timestamp " << _synchronization_timestamp << " in timeline 'matrix" << _matrix_tl_index
+            "Buffer not found for timestamp " << _synchronization_timestamp << " in timeline 'matrix"
+            << _matrix_tl_index
             << "'."
         );
     }
@@ -682,7 +687,7 @@ void synchronizer::set_delay(int _val, std::string _key)
      * it means that the value is a delay set for the i th frameTL
      * This works respectively for matrixDelay_i and matrixTL
      */
-    if(_key.rfind(slots::FRAME_DELAY_PREFIX, 0) == 0)
+    if(_key.starts_with(slots::FRAME_DELAY_PREFIX))
     {
         try
         {
@@ -706,7 +711,7 @@ void synchronizer::set_delay(int _val, std::string _key)
             SIGHT_ERROR("The frameTL index provided in the update delay slot is not a proper number: " << _key);
         }
     }
-    else if(_key.rfind(slots::MATRIX_DELAY_PREFIX, 0) == 0)
+    else if(_key.starts_with(slots::MATRIX_DELAY_PREFIX))
     {
         try
         {
