@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2024 IRCAD France
+ * Copyright (C) 2009-2025 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -31,10 +31,11 @@
 #include <core/spy_log.hpp>
 
 #include <data/helper/fiducials_series.hpp>
-#include <data/helper/medical_image.hpp>
 #include <data/image.hpp>
 #include <data/integer.hpp>
 
+#include <geometry/data/image.hpp>
+
 #include <service/macros.hpp>
 
 #include <ui/__/container/widget.hpp>
@@ -52,7 +53,7 @@
 namespace sight::module::ui::qt::image
 {
 
-namespace imHelper = data::helper::medical_image;
+namespace medical_image = data::helper::medical_image;
 
 static const core::com::slots::key_t UPDATE_SLICE_INDEX_SLOT = "updateSliceIndex";
 static const core::com::slots::key_t UPDATE_SLICE_TYPE_SLOT  = "updateSliceType";
@@ -60,11 +61,10 @@ static const core::com::slots::key_t UPDATE_SLICE_TYPE_SLOT  = "updateSliceType"
 const service::base::key_t slice_index_position_editor::IMAGE_INOUT =
     "image";
 
-std::map<data::helper::medical_image::orientation_t,
-         std::string> slice_index_position_editor::orientation_prefix_map = {
-    {data::helper::medical_image::orientation_t::axial, "S"},
-    {data::helper::medical_image::orientation_t::frontal, "P"},
-    {data::helper::medical_image::orientation_t::sagittal, "L"}
+std::map<slice_index_position_editor::axis_t, std::string> slice_index_position_editor::orientation_prefix_map = {
+    {slice_index_position_editor::axis_t::axial, "S"},
+    {slice_index_position_editor::axis_t::frontal, "P"},
+    {slice_index_position_editor::axis_t::sagittal, "L"}
 };
 
 //------------------------------------------------------------------------------
@@ -110,15 +110,15 @@ void slice_index_position_editor::configuring()
 
     if(orientation == "axial")
     {
-        m_orientation = orientation_t::axial; // Z
+        m_axis = axis_t::axial; // Z
     }
     else if(orientation == "frontal")
     {
-        m_orientation = orientation_t::frontal; // Y
+        m_axis = axis_t::frontal; // Y
     }
     else if(orientation == "sagittal")
     {
-        m_orientation = orientation_t::sagittal; // X
+        m_axis = axis_t::sagittal; // X
     }
     else
     {
@@ -135,74 +135,54 @@ void slice_index_position_editor::starting()
         this->get_container()
     );
 
-    const QString service_id = QString::fromStdString(get_id().substr(get_id().find_last_of('_') + 1));
+    const QString service_id = QString::fromStdString(base_id());
 
     auto* layout = new QVBoxLayout();
+    sight::ui::qt::slice_selector::ChangeIndexCallback fct_index = [this](int _index)
+                                                                   {
+                                                                       slice_index_notification(_index);
+                                                                   };
+    sight::ui::qt::slice_selector::ChangeTypeCallback fct_type = [this](int _type){slice_type_notification(_type);};
+    sight::ui::qt::slice_selector::ChangeLabelCallback fct_label = [this](){slice_label_notification();};
 
     if(m_label_option == label_option_t::index)
     {
-        sight::ui::qt::slice_selector::ChangeIndexCallback fct_index = [this](int _index)
-                                                                       {
-                                                                           slice_index_notification(_index);
-                                                                       };
-        sight::ui::qt::slice_selector::ChangeTypeCallback fct_type = [this](int _type){slice_type_notification(_type);};
-
         m_slice_selector_with_index = new sight::ui::qt::slice_selector(
             m_display_axis_selector,
             m_display_step_buttons,
             static_cast<std::uint8_t>(1)
 
         );
-
-        m_slice_selector_with_index->setProperty("class", "slice_selector");
-        m_slice_selector_with_index->set_enable(false);
-        m_slice_selector_with_index->setObjectName(service_id);
-
-        m_slice_selector_with_index->set_change_index_callback(fct_index);
-        m_slice_selector_with_index->set_change_type_callback(fct_type);
-        m_slice_selector_with_index->set_type_selection(m_orientation);
-
-        layout->addWidget(m_slice_selector_with_index);
-
-        layout->setContentsMargins(0, 0, 0, 0);
-
-        qt_container->set_layout(layout);
-
-        this->updating();
     }
     else if(m_label_option == label_option_t::position)
     {
-        sight::ui::qt::slice_selector::ChangeIndexCallback fct_index = [this](int _t){slice_index_notification(_t);};
-        sight::ui::qt::slice_selector::ChangeTypeCallback fct_type = [this](int _t){slice_type_notification(_t);};
-
-        m_slice_selector_with_position = new sight::ui::qt::slice_selector(
+        m_slice_selector_with_index = new sight::ui::qt::slice_selector(
             m_display_axis_selector,
             m_display_step_buttons,
             0.0
 
         );
-        m_slice_selector_with_position->setProperty("class", "slice_selector");
-        m_slice_selector_with_position->set_enabled(false);
-        m_slice_selector_with_position->setObjectName(service_id);
-
-        m_slice_selector_with_position->set_change_index_callback(fct_index);
-        m_slice_selector_with_position->set_change_type_callback(fct_type);
-        m_slice_selector_with_position->set_type_selection(m_orientation);
-
-        layout->addWidget(m_slice_selector_with_position);
-
-        m_slice_selector_with_position->set_prefix(orientation_prefix_map.at(m_orientation));
-
-        layout->setContentsMargins(0, 0, 0, 0);
-
-        qt_container->set_layout(layout);
-
-        this->updating();
-    }
-    else
-    {
-        SIGHT_ERROR("not a known value of label .");
     }
+
+    m_slice_selector_with_index->setProperty("class", "slice_selector");
+    m_slice_selector_with_index->set_enabled(false);
+    m_slice_selector_with_index->setObjectName(service_id);
+
+    m_slice_selector_with_index->set_change_index_callback(fct_index);
+    m_slice_selector_with_index->set_change_type_callback(fct_type);
+    m_slice_selector_with_index->set_change_label_callback(fct_label);
+
+    m_slice_selector_with_index->set_type_selection(m_axis);
+
+    layout->addWidget(m_slice_selector_with_index);
+
+    m_slice_selector_with_index->set_prefix(orientation_prefix_map.at(m_axis));
+
+    layout->setContentsMargins(0, 0, 0, 0);
+
+    qt_container->set_layout(layout);
+
+    this->updating();
 }
 
 //------------------------------------------------------------------------------
@@ -214,42 +194,46 @@ void slice_index_position_editor::updating()
 
         if(m_label_option == label_option_t::index)
         {
-            const bool image_is_valid = imHelper::check_image_validity(image.get_shared());
+            const bool image_is_valid = medical_image::check_image_validity(image.get_shared());
 
             m_slice_selector_with_index->set_enable(image_is_valid);
 
             m_axial_index = std::max(
                 std::int64_t(0),
-                imHelper::get_slice_index(*image, imHelper::orientation_t::axial).value_or(0)
+                medical_image::get_slice_index(*image, axis_t::axial).value_or(0)
             );
             m_frontal_index = std::max(
                 std::int64_t(0),
-                imHelper::get_slice_index(*image, imHelper::orientation_t::frontal).value_or(0)
+                medical_image::get_slice_index(*image, axis_t::frontal).value_or(0)
             );
             m_sagittal_index = std::max(
                 std::int64_t(0),
-                imHelper::get_slice_index(*image, imHelper::orientation_t::sagittal).value_or(0)
+                medical_image::get_slice_index(*image, axis_t::sagittal).value_or(0)
             );
 
             this->update_slice_index_from_img(*image);
         }
         else if(m_label_option == label_option_t::position)
         {
-            const bool image_is_valid = imHelper::check_image_validity(image.get_shared());
+            const bool image_is_valid = medical_image::check_image_validity(image.get_shared());
 
-            m_slice_selector_with_position->set_enabled(image_is_valid);
+            m_slice_selector_with_index->set_enabled(image_is_valid);
 
-            m_axial_position =
-                static_cast<double>(imHelper::get_slice_position(*image, imHelper::orientation_t::axial)
-                                    .value_or(image->origin()[2]));
+            const auto& origin = image->origin();
+            m_axial_position = medical_image::get_slice_position(
+                *image,
+                axis_t::axial
+            ).value_or(double(origin[axis_t::axial]));
 
-            m_frontal_position =
-                static_cast<double>(imHelper::get_slice_position(*image, imHelper::orientation_t::frontal)
-                                    .value_or(image->origin()[1]));
+            m_frontal_position = medical_image::get_slice_position(
+                *image,
+                axis_t::frontal
+            ).value_or(double(origin[axis_t::frontal]));
 
-            m_sagittal_position =
-                static_cast<double>(imHelper::get_slice_position(*image, imHelper::orientation_t::sagittal)
-                                    .value_or(image->origin()[0]));
+            m_sagittal_position = medical_image::get_slice_position(
+                *image,
+                axis_t::sagittal
+            ).value_or(double(origin[axis_t::sagittal]));
 
             this->update_slice_index_from_img(*image);
         }
@@ -265,56 +249,37 @@ void slice_index_position_editor::stopping()
     m_slice_selector_with_index = nullptr;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------------
 
+void slice_index_position_editor::destroyEditorContainer()
+{
+    auto qt_container = std::dynamic_pointer_cast<sight::ui::qt::container::widget>(
+        this->get_container()
+    );
+    qt_container->destroy_container();
+}
+
+//------------------------------------------------------
 void slice_index_position_editor::update_slice_index(int _axial, int _frontal, int _sagittal)
 {
-    if(m_label_option == label_option_t::index)
+    if(_sagittal != m_sagittal_index
+       || _frontal != m_frontal_index
+       || _axial != m_axial_index)
     {
-        if(_sagittal != m_sagittal_index
-           || _frontal != m_frontal_index
-           || _axial != m_axial_index)
-        {
-            m_sagittal_index = _sagittal;
-            m_frontal_index  = _frontal;
-            m_axial_index    = _axial;
-        }
+        m_sagittal_index = _sagittal;
+        m_frontal_index  = _frontal;
+        m_axial_index    = _axial;
 
         const auto image = m_image.lock();
 
-        namespace imHelper = imHelper;
+        medical_image::set_slice_index(*image, axis_t::axial, m_axial_index);
+        medical_image::set_slice_index(*image, axis_t::frontal, m_frontal_index);
+        medical_image::set_slice_index(*image, axis_t::sagittal, m_sagittal_index);
 
-        imHelper::set_slice_index(*image, orientation_t::axial, m_axial_index);
-        imHelper::set_slice_index(*image, orientation_t::frontal, m_frontal_index);
-        imHelper::set_slice_index(*image, orientation_t::sagittal, m_sagittal_index);
-
-        this->update_slice_index_from_img(*image);
-    }
-    else if(m_label_option == label_option_t::position)
-    {
-        const auto image = m_image.lock();
-
-        namespace imHelper = imHelper;
-
-        const auto& origin  = image->origin();
-        const auto& spacing = image->spacing();
-
-        double sagittal_p = origin[0] + _sagittal * spacing[0];
-        double frontal_p  = origin[1] + _frontal * spacing[1];
-        double axial_p    = origin[2] + _axial * spacing[2];
-
-        if(_sagittal != m_sagittal_index
-           || _frontal != m_frontal_index
-           || _axial != m_axial_index)
-        {
-            m_sagittal_position = sagittal_p;
-            m_frontal_position  = frontal_p;
-            m_axial_position    = axial_p;
-        }
-
-        imHelper::set_slice_position(*image, orientation_t::axial, m_axial_position);
-        imHelper::set_slice_position(*image, orientation_t::frontal, m_frontal_position);
-        imHelper::set_slice_position(*image, orientation_t::sagittal, m_sagittal_position);
+        const auto& origin = image->origin();
+        m_sagittal_position = medical_image::get_slice_position(*image, axis_t::sagittal).value_or(origin[sagittal]);
+        m_frontal_position  = medical_image::get_slice_position(*image, axis_t::frontal).value_or(origin[frontal]);
+        m_axial_position    = medical_image::get_slice_position(*image, axis_t::axial).value_or(origin[axial]);
 
         this->update_slice_index_from_img(*image);
     }
@@ -330,19 +295,19 @@ void slice_index_position_editor::info(std::ostream& /*_sstream*/)
 
 void slice_index_position_editor::update_slice_index_from_img(const sight::data::image& _image)
 {
-    if(imHelper::check_image_validity(_image))
+    if(medical_image::check_image_validity(_image))
     {
         if(m_label_option == label_option_t::index)
         {
             const auto image_size = _image.size();
             const auto index_ind  =
-                imHelper::get_slice_index(_image, m_orientation).value_or(image_size[m_orientation] / 2);
+                medical_image::get_slice_index(_image, m_axis).value_or(image_size[m_axis] / 2);
 
             // Update QSlider
             int max = 0;
-            if(_image.num_dimensions() > m_orientation)
+            if(_image.num_dimensions() > m_axis)
             {
-                max = static_cast<int>(image_size[m_orientation] - 1);
+                max = static_cast<int>(image_size[m_axis] - 1);
             }
 
             m_slice_selector_with_index->set_slice_range(0, max);
@@ -362,21 +327,21 @@ void slice_index_position_editor::update_slice_index_from_img(const sight::data:
 
             double max_position = 0.0;
 
-            if(_image.num_dimensions() > m_orientation)
+            if(_image.num_dimensions() > m_axis)
             {
-                max_position = static_cast<int>(image_size[m_orientation] - 1);
+                max_position = static_cast<int>(image_size[m_axis] - 1);
             }
 
             double min_position = 0.00;
 
-            m_slice_selector_with_position->set_position_range(min_position, max_position);
+            m_slice_selector_with_index->set_position_range(min_position, max_position);
 
             const auto index_position =
-                imHelper::get_slice_index(_image, m_orientation).value_or(image_size[m_orientation] / 2);
+                medical_image::get_slice_index(_image, m_axis).value_or(image_size[m_axis] / 2);
 
-            m_slice_selector_with_position->set_image_info(origin[m_orientation], spacing[m_orientation]);
-            m_slice_selector_with_position->set_position_text(static_cast<double>(index_position));
-            m_slice_selector_with_position->set_position_value(static_cast<int>(index_position));
+            m_slice_selector_with_index->set_image_info(origin[m_axis], spacing[m_axis]);
+            m_slice_selector_with_index->set_position_text(static_cast<double>(index_position));
+            m_slice_selector_with_index->set_position_value(static_cast<int>(index_position));
         }
     }
 }
@@ -386,40 +351,85 @@ void slice_index_position_editor::slice_index_notification(int _index)
 {
     const auto image = m_image.lock();
 
-    imHelper::set_slice_index(*image, m_orientation, _index);
+    medical_image::set_slice_index(*image, m_axis, _index);
 
     std::array idx {
-        static_cast<int>(imHelper::get_slice_index(
-                             *image,
-                             imHelper::orientation_t::sagittal
-        ).value_or(0)),
-        static_cast<int>(imHelper::get_slice_index(
-                             *image,
-                             imHelper::orientation_t::frontal
-        ).value_or(0)),
-        static_cast<int>(imHelper::get_slice_index(
-                             *image,
-                             imHelper::orientation_t::axial
-        ).value_or(0))
+        static_cast<int>(medical_image::get_slice_index(*image, axis_t::sagittal).value_or(0)),
+        static_cast<int>(medical_image::get_slice_index(*image, axis_t::frontal).value_or(0)),
+        static_cast<int>(medical_image::get_slice_index(*image, axis_t::axial).value_or(0))
     };
 
-    auto sig = image->signal<data::image::slice_index_modified_signal_t>(
-        data::image::SLICE_INDEX_MODIFIED_SIG
+    image->async_emit(this, data::image::SLICE_INDEX_MODIFIED_SIG, idx[2], idx[1], idx[0]);
+}
+
+//------------------------------------------------------------------------
+void slice_index_position_editor::slice_label_notification()
+{
+    m_label_option = (m_label_option == label_option_t::index) ? label_option_t::position : label_option_t::index;
+
+    this->destroyEditorContainer();
+    this->create();
+    auto* layout = new QVBoxLayout();
+
+    auto qt_container = std::dynamic_pointer_cast<sight::ui::qt::container::widget>(
+        this->get_container()
     );
-    core::com::connection::blocker block(sig->get_connection(this->slot(UPDATE_SLICE_INDEX_SLOT)));
-    sig->async_emit(idx[2], idx[1], idx[0]);
+
+    qt_container->set_layout(layout);
+
+    const QString service_id = QString::fromStdString(base_id());
+
+    if(m_label_option == label_option_t::index)
+    {
+        m_slice_selector_with_index = new sight::ui::qt::slice_selector(
+            m_display_axis_selector,
+            m_display_step_buttons,
+            static_cast<std::uint8_t>(1)
+
+        );
+    }
+    else if(m_label_option == label_option_t::position)
+    {
+        m_slice_selector_with_index = new sight::ui::qt::slice_selector(
+            m_display_axis_selector,
+            m_display_step_buttons,
+            0.0
+
+        );
+    }
+
+    sight::ui::qt::slice_selector::ChangeIndexCallback fct_index = [this](int _t){slice_index_notification(_t);};
+    sight::ui::qt::slice_selector::ChangeTypeCallback fct_type = [this](int _t){slice_type_notification(_t);};
+    sight::ui::qt::slice_selector::ChangeLabelCallback fct_label = [this](){slice_label_notification();};
+
+    m_slice_selector_with_index->setProperty("class", "slice_selector");
+    m_slice_selector_with_index->set_enable(true);
+
+    m_slice_selector_with_index->set_change_index_callback(fct_index);
+    m_slice_selector_with_index->set_change_type_callback(fct_type);
+    m_slice_selector_with_index->set_change_label_callback(fct_label);
+    m_slice_selector_with_index->set_type_selection(m_axis);
+    m_slice_selector_with_index->set_prefix(orientation_prefix_map.at(m_axis));
+
+    m_slice_selector_with_index->setObjectName(service_id);
+
+    layout->addWidget(m_slice_selector_with_index);
+
+    layout->setContentsMargins(0, 0, 0, 0);
+
+    this->updating();
 }
 
 //------------------------------------------------------------------------
 void slice_index_position_editor::update_slice_type(int _from, int _to)
 {
-    if(_to == static_cast<int>(m_orientation))
+    if(_to == static_cast<int>(m_axis))
     {
-        m_orientation = static_cast<orientation_t>(_from);
+        m_axis = static_cast<axis_t>(_from);
     }
-    else if(_from == static_cast<int>(m_orientation))
+    else if(_from == static_cast<int>(m_axis))
     {
-        m_orientation = static_cast<orientation_t>(_to);
+        m_axis = static_cast<axis_t>(_to);
     }
 
     if(m_label_option == label_option_t::index)
@@ -428,21 +438,21 @@ void slice_index_position_editor::update_slice_type(int _from, int _to)
     }
     else if(m_label_option == label_option_t::position)
     {
-        m_slice_selector_with_position->clear_slider_position();
+        m_slice_selector_with_index->clear_slider_position();
     }
 
-    this->update_slice_type_from_img(m_orientation);
+    this->update_slice_type_from_img(m_axis);
 }
 
 //--------------------------------------------------------------------------
 
-void slice_index_position_editor::update_slice_type_from_img(const orientation_t& _type)
+void slice_index_position_editor::update_slice_type_from_img(const axis_t& _type)
 {
     if(m_label_option == label_option_t::position)
     {
         const std::string& new_orientation_prefix = orientation_prefix_map.at(_type);
-        m_slice_selector_with_position->set_prefix(new_orientation_prefix);
-        m_slice_selector_with_position->set_type_selection(static_cast<int>(_type));
+        m_slice_selector_with_index->set_prefix(new_orientation_prefix);
+        m_slice_selector_with_index->set_type_selection(static_cast<int>(_type));
     }
     else if(m_label_option == label_option_t::index)
     {
@@ -468,7 +478,7 @@ void slice_index_position_editor::update_slider_fiducial()
         }
         else
         {
-            m_slice_selector_with_position->clear_slider_position();
+            m_slice_selector_with_index->clear_slider_position();
         }
 
         const auto fiducials_series = image_series->get_fiducials();
@@ -500,19 +510,7 @@ void slice_index_position_editor::update_slider_fiducial()
                     std::optional<std::int64_t> fiducial_position;
                     const std::array<double, 3> array_point = {point.x, point.y, point.z};
 
-                    if(m_label_option == label_option_t::index)
-                    {
-                        fiducial_position = imHelper::get_fiducial_slice_index(*image, array_point, m_orientation);
-                    }
-                    else
-                    {
-                        fiducial_position =
-                            static_cast<std::int64_t>(imHelper::get_fiducial_slice_position(
-                                                          *image,
-                                                          array_point,
-                                                          m_orientation
-                            ).value_or(-1));
-                    }
+                    fiducial_position = geometry::data::get_fiducial_slice_index(*image, array_point, m_axis);
 
                     if(fiducial_position.has_value())
                     {
@@ -522,9 +520,8 @@ void slice_index_position_editor::update_slider_fiducial()
                         }
                         else
                         {
-                            m_slice_selector_with_position->add_position_slider(
-                                static_cast<double>(fiducial_position.
-                                                    value()),
+                            m_slice_selector_with_index->add_position_slider(
+                                static_cast<double>(fiducial_position.value()),
                                 color
                             );
                         }
@@ -539,30 +536,24 @@ void slice_index_position_editor::update_slider_fiducial()
 
 void slice_index_position_editor::slice_type_notification(int _type)
 {
-    auto type = static_cast<orientation_t>(_type);
+    auto type = static_cast<axis_t>(_type);
     SIGHT_ASSERT(
         "Bad slice type " << type,
-        type == orientation_t::x_axis
-        || type == orientation_t::y_axis
-        || type == orientation_t::z_axis
+        type == axis_t::x_axis
+        || type == axis_t::y_axis
+        || type == axis_t::z_axis
     );
 
-    const auto old_type = m_orientation;
+    const auto old_type = m_axis;
 
     // Change slice type
-    m_orientation = static_cast<orientation_t>(type);
+    m_axis = type;
 
     // Fire the signal
     {
         const auto image = m_image.const_lock();
+        image->async_emit(this, data::image::SLICE_TYPE_MODIFIED_SIG, static_cast<int>(old_type), _type);
 
-        auto sig = image->signal<data::image::slice_type_modified_signal_t>(
-            data::image::SLICE_TYPE_MODIFIED_SIG
-        );
-        {
-            core::com::connection::blocker block(sig->get_connection(this->slot(UPDATE_SLICE_TYPE_SLOT)));
-            sig->async_emit(old_type, _type);
-        }
         this->update_slice_index_from_img(*image);
     }
 }
@@ -575,9 +566,10 @@ service::connections_t slice_index_position_editor::auto_connections() const
     connections.push(IMAGE_INOUT, data::image::MODIFIED_SIG, service::slots::UPDATE);
     connections.push(IMAGE_INOUT, data::image::SLICE_INDEX_MODIFIED_SIG, UPDATE_SLICE_INDEX_SLOT);
     connections.push(IMAGE_INOUT, data::image::SLICE_TYPE_MODIFIED_SIG, UPDATE_SLICE_TYPE_SLOT);
+
     connections.push(IMAGE_INOUT, data::image::BUFFER_MODIFIED_SIG, service::slots::UPDATE);
-    connections.push(IMAGE_INOUT, data::image::DISTANCE_MODIFIED_SIG, service::slots::UPDATE);
-    connections.push(IMAGE_INOUT, data::image::DISTANCE_REMOVED_SIG, service::slots::UPDATE);
+    connections.push(IMAGE_INOUT, data::image::RULER_MODIFIED_SIG, service::slots::UPDATE);
+    connections.push(IMAGE_INOUT, data::image::FIDUCIAL_REMOVED_SIG, service::slots::UPDATE);
 
     const auto image        = m_image.lock();
     const auto image_series = std::dynamic_pointer_cast<const sight::data::image_series>(image.get_shared());
@@ -588,6 +580,7 @@ service::connections_t slice_index_position_editor::auto_connections() const
         connections.push(IMAGE_INOUT, data::has_fiducials::signals::GROUP_REMOVED, service::slots::UPDATE);
         connections.push(IMAGE_INOUT, data::has_fiducials::signals::POINT_REMOVED, service::slots::UPDATE);
         connections.push(IMAGE_INOUT, data::has_fiducials::signals::POINT_ADDED, service::slots::UPDATE);
+        connections.push(IMAGE_INOUT, data::has_fiducials::signals::POINT_MODIFIED, service::slots::UPDATE);
     }
 
     return connections;
