@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2020-2024 IRCAD France
+ * Copyright (C) 2020-2025 IRCAD France
  * Copyright (C) 2020-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -185,7 +185,7 @@ void shape_extruder::configuring()
 
 void shape_extruder::starting()
 {
-    this->adaptor::initialize();
+    adaptor::init();
 
     this->render_service()->make_current();
 
@@ -199,31 +199,18 @@ void shape_extruder::starting()
     // Create entities.
     Ogre::SceneManager* const scene_mng = this->get_scene_manager();
 
-    m_lasso_node = scene_mng->getRootSceneNode()->createChildSceneNode(this->get_id() + "_lassoNode");
+    m_lasso_node = scene_mng->getRootSceneNode()->createChildSceneNode(gen_id("lassoNode"));
 
-    m_lasso           = scene_mng->createManualObject(this->get_id() + "_lasso");
-    m_last_lasso_line = scene_mng->createManualObject(this->get_id() + "_lastLassoLine");
+    m_lasso           = scene_mng->createManualObject(gen_id("lasso"));
+    m_last_lasso_line = scene_mng->createManualObject(gen_id("lastLassoLine"));
 
     m_lasso_node->attachObject(m_lasso);
     m_lasso_node->attachObject(m_last_lasso_line);
 
     // Create the material.
-    m_material = std::make_shared<data::material>();
-
-    m_material_adaptor = this->register_service<module::viz::scene3d::adaptor::material>(
-        "sight::module::viz::scene3d::adaptor::material"
-    );
-    m_material_adaptor->set_inout(m_material, module::viz::scene3d::adaptor::material::MATERIAL_INOUT, true);
-    m_material_adaptor->configure(
-        this->get_id() + m_material_adaptor->get_id(),
-        this->get_id() + m_material_adaptor->get_id(),
-        this->render_service(),
-        m_layer_id,
-        "ambient"
-    );
-    m_material_adaptor->start();
-    m_material_adaptor->get_material_fw()->set_has_vertex_color(true);
-    m_material_adaptor->update();
+    m_material = std::make_unique<sight::viz::scene3d::material::standard>(gen_id("material"));
+    m_material->set_layout(sight::data::mesh::attribute::point_colors);
+    m_material->set_shading(sight::data::material::shading_t::ambient, this->layer()->num_lights());
 }
 
 //-----------------------------------------------------------------------------
@@ -239,7 +226,6 @@ void shape_extruder::stopping()
     this->render_service()->make_current();
 
     // Destroy the material.
-    this->unregister_services();
     m_material.reset();
 
     // Destroy entities.
@@ -256,6 +242,8 @@ void shape_extruder::stopping()
     const sight::viz::scene3d::interactor::base::sptr interactor =
         std::dynamic_pointer_cast<sight::viz::scene3d::interactor::base>(this->get_sptr());
     layer->remove_interactor(interactor);
+
+    adaptor::deinit();
 }
 
 //-----------------------------------------------------------------------------
@@ -417,7 +405,7 @@ void shape_extruder::modify_lasso(action _action, int _x, int _y)
             // Compute the plane where the tool will work.
             // This plane allows to generate all points of the lasso on the same plane to simplify further algorithms.
             const Ogre::Camera* const camera = layer->get_default_camera();
-            const Ogre::Vector3 direction    = this->get_cam_direction(camera);
+            const Ogre::Vector3 direction    = shape_extruder::get_cam_direction(camera);
 
             // Compute the near plane and the far plane.
             const Ogre::Vector3 cam_pos = camera->getDerivedPosition();
@@ -497,7 +485,7 @@ void shape_extruder::modify_lasso(action _action, int _x, int _y)
         SIGHT_ASSERT("Lasso positions must have at east one point", !m_lasso_tool_positions.empty());
 
         m_last_lasso_line->begin(
-            m_material_adaptor->get_material_name(),
+            m_material->name(),
             Ogre::RenderOperation::OT_LINE_STRIP,
             sight::viz::scene3d::RESOURCE_GROUP
         );
@@ -677,7 +665,7 @@ void shape_extruder::draw_lasso()
 
     // Draw the lasso line.
     m_lasso->begin(
-        m_material_adaptor->get_material_name(),
+        m_material->name(),
         Ogre::RenderOperation::OT_LINE_STRIP,
         sight::viz::scene3d::RESOURCE_GROUP
     );
@@ -698,7 +686,7 @@ void shape_extruder::draw_lasso()
     {
         // Begin a new section.
         m_lasso->begin(
-            m_material_adaptor->get_material_name(),
+            m_material->name(),
             Ogre::RenderOperation::OT_TRIANGLE_LIST,
             sight::viz::scene3d::RESOURCE_GROUP
         );
@@ -1116,7 +1104,7 @@ std::list<Ogre::Vector2> shape_extruder::add_constraints(
     if(!found)
     {
         const Ogre::Vector2 mid_point = (_edge.a + _edge.b) / 2.F;
-        this->add_delaunay_point(_triangulation, mid_point);
+        shape_extruder::add_delaunay_point(_triangulation, mid_point);
 
         const int depth                      = _depth + 1;
         std::list<Ogre::Vector2> front_added = this->add_constraints(_triangulation, edge(_edge.a, mid_point), depth);
